<?xml version="1.0" encoding="UTF-8"?>
<!--
 		Licensed Materials - Property of IBM
 			xxxx-xxx
 		Â© Copyright IBM Corporation 2022. All rights reserved.
 		US Government Users Restricted Rights - Use, duplication or disclosure
 		restricted by GSA ADP Schedule Contract with IBM Corp.
 
 The source code for this program is not published or otherwise
 divested of its trade secrets, irrespective of what has been
 deposited with the U.S. Copyright Office.
-->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
					xmlns:fo="http://www.w3.org/1999/XSL/Format"
					xmlns:fox="http://xmlgraphics.apache.org/fop/extensions"
					xmlns="http://www.w3.org/2000/svg">
		
	<!-- color constants -->
	<xsl:variable name="TextBlueColor" select="'blue'"/>
	<xsl:variable name="TextGreyColor" select="'#404040'"/>
	<xsl:variable name="TextWhiteColor" select="'white'"/>
	<xsl:variable name="TextBlackColor" select="'black'"/>
	<xsl:variable name="HeaderBgColor" select="'404040'"/>
	<xsl:variable name="GreenBgColor" select="'#008000'"/>
	<xsl:variable name="LinesGreyColor" select="'#e3e4e6'"/>
	<xsl:variable name="BlueBgColor" select="'#3d70b2'"/>
	<xsl:variable name="YellowBgColor" select="'#efc100'"/>
	<xsl:variable name="RedBgColor" select="'#c60000'"/>
			
	<!-- page constants -->
	<xsl:variable name="NoFilterThreshold" select="101"/>
	<xsl:variable name="PageTitleFontSize" select="16"/>
	<xsl:variable name="FontSize" select = "8"/>
	<xsl:variable name="HeaderFontSize" select="8"/>
	<xsl:variable name="IndentWidth" select="5"/>
	<xsl:variable name="TableOfContentMargin" select="3"/>
	<xsl:variable name="PercentColMarginBottom" select="1"/>
	<xsl:variable name="LineSize" select="1"/>
	<xsl:variable name="PageLeftRightMargin" select="40"/>
	<xsl:variable name="PageTopBottomMargin" select="40"/>
	<xsl:variable name="PageFooterHeaderCallbackSize" select="50"/>
	<xsl:variable name="Page1HeaderCallbackSize" select="0"/>
	<xsl:variable name="FontTypeCourier">
		<xsl:choose>
			<xsl:when test="/report[@language='zh']">Microsoft YaHei</xsl:when>
			<xsl:when test="/report[@language='zh_CN']">Microsoft YaHei</xsl:when>
			<xsl:when test="/report[@language='zh_TW']">Microsoft JhengHei</xsl:when>
			<xsl:when test="/report[@language='ko']">IBMPlexSansKO</xsl:when>
			<xsl:when test="/report[@language='ja']">IBMPlexSansJA</xsl:when>
			<xsl:when test="/report[@language='en']">IBMPlexMono</xsl:when>
			<xsl:when test="/report[@language='ar']">IBMPlexSansArabic</xsl:when>
			<xsl:otherwise>IBMPlexMono</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="LineHitMarker" select="'H'"/>
	
	<xsl:variable name="DefaultPdfFont">
		<xsl:choose>
			<xsl:when test="/report[@language='zh']">Microsoft YaHei</xsl:when>
			<xsl:when test="/report[@language='zh_CN']">Microsoft YaHei</xsl:when>
			<xsl:when test="/report[@language='zh_TW']">Microsoft JhengHei</xsl:when>
			<xsl:when test="/report[@language='ko']">IBMPlexSansKO</xsl:when>
			<xsl:when test="/report[@language='ja']">IBMPlexSansJA</xsl:when>
			<xsl:when test="/report[@language='en']">IBMPlexSans</xsl:when>
			<xsl:when test="/report[@language='ar']">IBMPlexSansArabic</xsl:when>
			<xsl:otherwise>IBMPlexSans</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:template match="report">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format"
			xmlns:fox="http://xmlgraphics.apache.org/fop/extensions"
			xmlns="http://www.w3.org/2000/svg"
			language="{substring(@language,1,2)}">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="summary_first" 
	  				page-height="{@pageHeight}" page-width="{@pageWidth}"
	  				margin-top="{$PageTopBottomMargin}" 
	  				margin-bottom="{$PageTopBottomMargin}" 
	  				margin-left="{$PageLeftRightMargin}" 
	  				margin-right="{$PageLeftRightMargin}">
	    			<fo:region-body/>
	    			<fo:region-after extent="0.625in"/>
	  			</fo:simple-page-master>
	  			<fo:simple-page-master master-name="summary_rest" 
	  				page-height="{@pageHeight}" page-width="{@pageWidth}" 
	  				margin-top="{$PageTopBottomMargin}" 
	  				margin-bottom="{$PageTopBottomMargin}" 
	  				margin-left="{$PageLeftRightMargin}" 
	  				margin-right="{$PageLeftRightMargin}">
	    			<fo:region-body/>
	    			<fo:region-before extent="0.9in"/>
	    			
	    			<fo:region-after extent="0.625in"/>
	    			
	  			</fo:simple-page-master>
	  			<fo:page-sequence-master 
	                    master-name="summary">
	                    <fo:repeatable-page-master-alternatives>
	                                <fo:conditional-page-master-reference
	                                        master-reference="summary_first"
	                                        page-position="first" />
	                                <fo:conditional-page-master-reference
	                                        master-reference="summary_rest"
	                                        page-position="rest" />
	                    </fo:repeatable-page-master-alternatives>
	            </fo:page-sequence-master>
				<fo:simple-page-master master-name="other" 
  					page-height="{@pageHeight}" page-width="{@pageWidth}"
  					margin-top="{$PageTopBottomMargin}" 
  					margin-bottom="{$PageTopBottomMargin}" 
  					margin-left="{$PageLeftRightMargin}" 
  					margin-right="{$PageLeftRightMargin}">
    				<fo:region-body margin-top="25"
    								margin-bottom="0.630in"/>
    				<fo:region-before extent="0.9in"/>
    			
    				<fo:region-after extent="0.625in"/>
    			
  				</fo:simple-page-master>
  	
				
			</fo:layout-master-set>
			
			<!-- set document title for accessibility -->
			<fo:declarations>
				<pdf:catalog xmlns:pdf="http://xmlgraphics.apache.org/fop/extensions/pdf">
                   	<pdf:dictionary type="normal" key="ViewerPreferences">
                       	<pdf:boolean key="DisplayDocTitle">true</pdf:boolean>
                   	</pdf:dictionary>
               	</pdf:catalog>
				<x:xmpmeta xmlns:x="adobe:ns:meta/">
					<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
						<rdf:Description rdf:about="" xmlns:dc="http://purl.org/dc/elements/1.1/">
							<dc:title><xsl:value-of select="@title"/></dc:title>
		    			</rdf:Description>
	  				</rdf:RDF>
  				</x:xmpmeta>
			</fo:declarations>
			
			<fo:bookmark-tree>
				<xsl:for-each select="/report/page">
					<fo:bookmark internal-destination="{generate-id(.)}" starting-state="show">
						<fo:bookmark-title>
							<xsl:value-of select="./title"/>
							</fo:bookmark-title>
					</fo:bookmark>
					<xsl:if test="position()=1">
						<fo:bookmark internal-destination="tocPage" starting-state="show">
							<fo:bookmark-title>
								<xsl:value-of select="./tableOfContents"/>
							</fo:bookmark-title>
						</fo:bookmark>
					</xsl:if>
					
				</xsl:for-each>
     		</fo:bookmark-tree>
			<xsl:apply-templates/>

		</fo:root>
	</xsl:template>
	
	<xsl:template name="genTOC">
		<xsl:param name = "title"/>
		<fo:page-sequence master-reference="other"
			country="us" language="en" id="tocPage">
			<fo:static-content flow-name="xsl-region-before">
				<xsl:call-template name="header"/>
			</fo:static-content>
  			<fo:static-content flow-name="xsl-region-after">
				<xsl:call-template name="footer"/>
			</fo:static-content>
			<fo:flow flow-name="xsl-region-body">
				<fo:block text-align="center"
					font-size="16pt"
					font-family="{$DefaultPdfFont}"
					font-weight="bold" 
					id="tocPage">	
      				<xsl:value-of select="$title" />
      				<fo:block><fo:leader/></fo:block>
      				<fo:block><fo:leader/></fo:block>
      			</fo:block>
				<xsl:for-each select="/report/page">
		      		<fo:block-container height="20pt"
		                   		display-align="center">
				        <fo:block text-align-last="justify"
				        			font-family="{$DefaultPdfFont}"
						        	font-weight="bold"
						        	font-size="{$HeaderFontSize}">
				        	<fo:basic-link internal-destination="{generate-id(.)}">
				        		<xsl:value-of select="count(preceding::page) + 1" />
								<xsl:text> - </xsl:text>
								<xsl:value-of select="tocTitle" />
								<fo:leader leader-pattern="dots" />
								<fo:page-number-citation ref-id="{generate-id(.)}" />
				          	</fo:basic-link>
				        </fo:block>
		        	</fo:block-container>
        		</xsl:for-each>
			</fo:flow>
		</fo:page-sequence>
      	
	</xsl:template>

	<xsl:template name="header">
        
        <fo:table width="100%" table-layout="fixed">
        	<fo:table-column column-width="80%" fox:header="true"/>
 			<fo:table-column column-width="20%"/>
           	<fo:table-body>
               	<fo:table-row height="20pt">
               		<fo:table-cell>
               			<fo:block/>
               		</fo:table-cell>
                   	<fo:table-cell>
                   		<fo:block-container height="20pt"
                   							background-color="#404040"
	        								fox:border-radius="5pt"
	        								display-align="center">
	                   		<fo:block text-align="center"
	                   			
	        					font-family="{$DefaultPdfFont}"
	        					font-weight="bold"
	        					font-size="{$HeaderFontSize}">
	       						
					        	<fo:basic-link internal-destination="docStart" color="white">
					            	<xsl:value-of select="//rectangle"/>  
					            </fo:basic-link>
					            
					        </fo:block>
				        </fo:block-container>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
        
	</xsl:template>
	<xsl:template name="footer">
		<fo:block>
			<fo:leader leader-pattern="rule" leader-length="100%" rule-style="solid" rule-thickness="1pt"/>             
		</fo:block>
        <fo:block text-align-last="justify"
        			font-size="9pt"
        			font-family="{$DefaultPdfFont}"
        			font-weight="bold">
        	<fo:inline>
				<xsl:value-of select="//date"/>
			</fo:inline>
			<fo:leader/>
			<fo:inline>
				<xsl:call-template name="pageLine"/>
			</fo:inline>
		</fo:block>
        
    </xsl:template>
	
	
	<xsl:template match="page[@kind='summary']">	
		<fo:page-sequence master-reference="summary"
			country="us" language="en" id="{generate-id(.)}">
			<fo:static-content flow-name="xsl-region-before">
				<xsl:call-template name="header"/>
			</fo:static-content>
  			<fo:static-content flow-name="xsl-region-after">
				<xsl:call-template name="footer"/>
			</fo:static-content>
			<fo:flow flow-name="xsl-region-body">
				<fo:block id="{generate-id()}"/>
				<fo:block text-align="center"
					font-size="16pt"
					font-family="{$DefaultPdfFont}"
					font-weight="bold" 
					id="docStart">	
      				<xsl:value-of select="./title" />
      			
      			</fo:block>
      			<fo:block><fo:leader/></fo:block>
      			<fo:block><fo:leader/></fo:block>
  				<xsl:apply-templates/>
    		</fo:flow>
		</fo:page-sequence>
		<xsl:call-template name="genTOC">
			<xsl:with-param name="title" select="./tableOfContents"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="page[@kind!='summary']">
	
		<fo:page-sequence master-reference="other"
			country="us" language="en" id="{generate-id(.)}">
			<fo:static-content flow-name="xsl-region-before">
				<xsl:call-template name="header"/>
			</fo:static-content>
  			<fo:static-content flow-name="xsl-region-after">
				<xsl:call-template name="footer"/>
			</fo:static-content>
			<fo:flow flow-name="xsl-region-body">
				<fo:block id="{generate-id()}"/>
				<xsl:if test="@file">
					<fo:block id="{@file}"></fo:block>
				</xsl:if>
				<xsl:if test="@module">
					<fo:block id="{@module}"></fo:block>
				</xsl:if>
				<fo:block text-align="center" 
					font-size="16pt"
					font-family="{$DefaultPdfFont}"
					font-weight="bold">	
      				<xsl:value-of select="./title" />
      				<fo:block><fo:leader/></fo:block>
      				<fo:block><fo:leader/></fo:block>
      			</fo:block>
      			<xsl:apply-templates/>
      			
      			<xsl:if test="count(preceding-sibling::page) + 1 = count(../page) and count(../sourcePage) = 0">
      				<fo:block id="lastPage"> </fo:block>
      			</xsl:if>
    		</fo:flow>
		</fo:page-sequence>
		
	</xsl:template>
	
	<xsl:template match="sourcePage">
		<fo:page-sequence master-reference="other"
			country="us" language="en" id="{generate-id(.)}">
			<fo:static-content flow-name="xsl-region-before">
				<xsl:call-template name="header"/>
			</fo:static-content>
  			<fo:static-content flow-name="xsl-region-after">
				<xsl:call-template name="footer"/>
			</fo:static-content>
			<fo:flow flow-name="xsl-region-body">
				<fo:block id="{generate-id(.)}"/>
				<fo:block text-align="center" 
					font-size="16pt"
					font-family="{$DefaultPdfFont}"
					font-weight="bold">	
      				<xsl:value-of select="./title" />
      				<fo:block><fo:leader/></fo:block>
      				<fo:block><fo:leader/></fo:block>
      			</fo:block>
      			<fo:table width="100%" table-layout="fixed">
					<fo:table-column column-width="5%" display-align="after"/>
					<xsl:choose>
						<xsl:when test="@isCompare = 'true'">
							<fo:table-column column-width="1.1%" display-align="after"/>
							<fo:table-column column-width="1.1%" display-align="after"/>
							<fo:table-column column-width="92.8%" fox:header="true"  display-align="after"/>
						</xsl:when>
						<xsl:otherwise>
							<fo:table-column column-width="1.1%" display-align="after"/>
							<fo:table-column column-width="93.9%" fox:header="true" display-align="after"/>
 			
						</xsl:otherwise>
					</xsl:choose>
					
 					<fo:table-body>
 						<xsl:apply-templates />
 					</fo:table-body>
 				</fo:table>
      			<xsl:if test="count(preceding-sibling::sourcePage) + 1 = count(../sourcePage)">
      				<fo:block id="lastPage"> </fo:block>
      			</xsl:if>
    		</fo:flow>
		</fo:page-sequence>
	</xsl:template>
	
	<xsl:template match="srcLine">
		<fo:table-row>
			<fo:table-cell display-align="after">
				<fo:block font-size="9"
					  font-family="{$FontTypeCourier}"
					  font-weight="bold"
					  text-align="right">
					 
						<xsl:value-of select="@lineNum"/>
				</fo:block>
			</fo:table-cell>
			
			<xsl:if test="@prevcovered">
				<xsl:call-template name="coverageCell">
					<xsl:with-param name="covered" select="@prevcovered"/>
					<xsl:with-param name="coverageAltText" select="@prevCoverageAltText"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="@covered">
				<xsl:call-template name="coverageCell">
					<xsl:with-param name="covered" select="@covered"/>
					<xsl:with-param name="coverageAltText" select="@coverageAltText"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="@prevCoveredTxt">
				<xsl:call-template name="coverageTxtCell">
					<xsl:with-param name="covered" select="@prevCoveredTxt"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="@coveredTxt">
				<xsl:call-template name="coverageTxtCell">
					<xsl:with-param name="covered" select="@coveredTxt"/>
				</xsl:call-template>
			</xsl:if>
			<fo:table-cell margin-left="10" display-align="after">
				<fo:block id="{@id}"/>
				<fo:block font-size="9"
					  font-family="{$FontTypeCourier}"
					  font-weight="bold"
					  white-space="pre"
					  wrap-option="wrap">
					<xsl:attribute name="color">
						<xsl:choose>
							<xsl:when test="@covered!='undef' or @coveredTxt != ''">
								<xsl:value-of select="$TextBlueColor"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$TextGreyColor"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					  
					<xsl:value-of select="."/>	  
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	
	<xsl:template match="table">
		<fo:table width="100%" table-layout="fixed">
			<xsl:variable name="flexSum" select="sum(./column/@flex)"/>
			<xsl:for-each select="column">
				<xsl:variable name = "width" 
				select = "concat(string(100 * @flex div $flexSum),'%')"/>
				<fo:table-column column-width="{$width}">
					<xsl:if test="position()=1">
						<xsl:attribute name="fox:header">true</xsl:attribute>
					</xsl:if>
				</fo:table-column>
 			</xsl:for-each>
 			<fo:table-body>
 				<xsl:apply-templates />
 			</fo:table-body>
 		</fo:table>
 		<fo:block><fo:leader/></fo:block>
	       						
	</xsl:template>
	
	<xsl:template match="table/tableHeader">
		<fo:table-row min-height="20pt" display-align="center" background-color="{$HeaderBgColor}">
			<xsl:apply-templates/>
		</fo:table-row>
	</xsl:template>
	<xsl:template match="table/tableHeader/cell">
		
		<fo:table-cell margin-left="2" margin-right="2">
			<fo:block-container display-align="center" min-height="20pt">
				<fo:block color="white"
					font-family="{$DefaultPdfFont}"
	        		font-weight="bold"
	        		font-size="{$HeaderFontSize}">
	        		<xsl:call-template name="textAlignAttr"/>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:block-container>
		</fo:table-cell>
	</xsl:template>
	
	<xsl:template name="textAlignAttr">
		<xsl:attribute name="text-align">
			<xsl:choose>
				<xsl:when test="@align">
  					<xsl:value-of select="@align"/>
				</xsl:when>
				<xsl:otherwise>left</xsl:otherwise>
			</xsl:choose>
     	</xsl:attribute>
	</xsl:template>
	
	<xsl:template match="table[@id !='fileTable' and @id != 'moduleTable' and @id != 'functionTable']/row">
		<fo:table-row display-align="center" min-height="20pt">
			<xsl:apply-templates/>
		</fo:table-row>
	</xsl:template>
	
	<xsl:template match="table[@id='fileTable' or @id='moduleTable' or @id='functionTable']/row">
		<fo:table-row min-height="20pt"
			border-bottom-width="1"
			border-bottom-color="{$LinesGreyColor}"
			border-bottom-style="solid"
			display-align="center">
			<xsl:apply-templates/>
		</fo:table-row>
	</xsl:template>
	
	<xsl:template match="table/row/cell">
		<fo:table-cell margin-left="2"
				margin-right="2">
			<fo:block-container display-align="center" min-height="20pt">
				<xsl:if test="../@id='ccresultFile'">
					<xsl:attribute name="margin-top">5pt</xsl:attribute>
				</xsl:if>
				<fo:block font-size="{$HeaderFontSize}"
					font-family="{$DefaultPdfFont}"
					font-weight="bold" text-indent="{@indent}"
					wrap-option="wrap">
					<xsl:call-template name="textAlignAttr"/>
					<xsl:choose>
						<xsl:when test="@href">
							<fo:basic-link internal-destination="{@href}">
								<xsl:apply-templates/>
							</fo:basic-link>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates/>
						</xsl:otherwise>
					</xsl:choose>
					
				</fo:block>

			</fo:block-container>
		</fo:table-cell>
	</xsl:template>
	
	<xsl:template match="table/row/cell/image">
		
		<fo:external-graphic
			content-height="scale-to-fit"
			height="7" padding-right="2" padding-left="2"
			fox:alt-text="{/report/img[@src=current()/@src]/@description}">
			<xsl:attribute name="src">
				<xsl:value-of select="/report/img[@src=current()/@src]"/>
			</xsl:attribute>
		</fo:external-graphic>
	</xsl:template>
	
	<xsl:template name="coverageCell">
		<xsl:param name="covered"/>
		<xsl:param name="coverageAltText"/>
		<fo:table-cell>
			<xsl:attribute name="background-color">
				<xsl:choose>
					<xsl:when test="$covered = 'true'">
			  			<xsl:value-of select="$GreenBgColor"/>
					</xsl:when>
					<xsl:when test="$covered = 'false'">
	  					<xsl:value-of select="$RedBgColor"/>
	  				</xsl:when>
	  				<xsl:otherwise>white</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<fo:block font-family="{$DefaultPdfFont}"
       					font-weight="bold"
       					font-size="{$HeaderFontSize}">
				<xsl:choose>
					<xsl:when test="$covered = 'true' or $covered = 'false'">
						<xsl:call-template name="greenRedRect">
							<xsl:with-param name="covered" select="$covered"/>
							<xsl:with-param name="coverageAltText" select="$coverageAltText"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$covered = '+' or $covered='-'">
							<xsl:value-of select="$covered"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>

	</xsl:template>
	
	<xsl:template name="coverageTxtCell">
		<xsl:param name="covered"/>
		<fo:table-cell display-align="after">
			<fo:block font-family="{$FontTypeCourier}"
						font-weight="bold"
						font-size="9">
				<xsl:attribute name="color">
					<xsl:choose>
						<xsl:when test="$covered = $LineHitMarker"><xsl:value-of select="$GreenBgColor"/></xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$RedBgColor"/>
						</xsl:otherwise>
					</xsl:choose>
					
				</xsl:attribute>
				<xsl:value-of select="$covered"/>
			</fo:block>
		</fo:table-cell>
	</xsl:template>
	
	<xsl:template name="greenRedRect">
		<xsl:param name="covered"/>
		<xsl:param name="coverageAltText"/>
		<fo:instream-foreign-object width="100%" height="{$FontSize}"
			content-height="scale-to-fit"
			content-width="scale-to-fit"
			fox:alt-text="${coverAltText}">
			<svg width="100%" height="{$FontSize}">
   				<rect width="100%" height="{$FontSize}">
   					<xsl:attribute name="fill">
						<xsl:choose>
							<xsl:when test="$covered = 'true'">
			  					<xsl:value-of select="$GreenBgColor"/>
							</xsl:when>
							<xsl:when test="$covered = 'false'">
			  					<xsl:value-of select="$RedBgColor"/>
							</xsl:when>
						</xsl:choose>
					</xsl:attribute>
				</rect>
			</svg> 
		</fo:instream-foreign-object>
	</xsl:template>
	
	<xsl:template match="table/row/cell/ccBar">
		<xsl:variable name="ccValueNum" 
			select="number(substring(@ccValue,1,string-length(@ccValue) - 1))"/>
		<fo:instream-foreign-object width="100%" content-width="scale-to-fit">
			<xsl:attribute name="fox:alt-text">
				<xsl:choose>
					<xsl:when test="$ccValueNum >= 70">
	  					<xsl:value-of select="/report/levels/@high"/>
					</xsl:when>
					<xsl:when test="$ccValueNum &lt; 30">
	  					<xsl:value-of select="/report/levels/@moderate"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="/report/levels/@low"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<svg width="100%" height="14">
   				<rect width="100%" height="14" fill="{$LinesGreyColor}" 
   				style="stroke-width:1; stroke:{$LinesGreyColor}" />
   				<rect width="{@ccValue}" height="14" fill="{$BlueBgColor}" 
   				style="stroke-width:1; stroke:{$LinesGreyColor}">
   					<xsl:attribute name="fill">
						<xsl:choose>
							<xsl:when test="$ccValueNum >= 70">
			  					<xsl:value-of select="$BlueBgColor"/>
							</xsl:when>
							<xsl:when test="$ccValueNum &lt; 30">
			  					<xsl:value-of select="$RedBgColor"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$YellowBgColor"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</rect>
			</svg> 
		</fo:instream-foreign-object>
	</xsl:template>
	
    <xsl:template match="page"/>
    
    <xsl:template match="*"/>

	<xsl:template name="pageLine">
		<xsl:value-of select="//@pageLbl"/>&#x00A0;<fo:page-number/>&#x00A0;<xsl:value-of select="//@ofLbl"/>&#x00A0;
		<fo:page-number-citation ref-id="lastPage"/>
		
	</xsl:template>
	

</xsl:stylesheet>